"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runCli = runCli;
const commander_1 = require("commander");
const logger_util_js_1 = require("../utils/logger.util.js");
const constants_util_js_1 = require("../utils/constants.util.js");
const export_cli_js_1 = __importDefault(require("./export.cli.js"));
/**
 * CLI entry point for the Boilerplate MCP Server
 * Handles command registration, parsing, and execution
 */
// Package description
const DESCRIPTION = 'CLI tool for exporting Confluence content.';
/**
 * Run the CLI with the provided arguments
 *
 * @param args Command line arguments to process
 * @returns Promise that resolves when CLI command execution completes
 */
async function runCli(args) {
    const cliLogger = logger_util_js_1.Logger.forContext('cli/index.ts');
    cliLogger.debug('Initializing CLI with arguments', args);
    const program = new commander_1.Command();
    program.name(constants_util_js_1.CLI_NAME).version(constants_util_js_1.VERSION).description(DESCRIPTION);
    // Register CLI commands
    cliLogger.debug('Registering CLI commands...');
    export_cli_js_1.default.register(program);
    cliLogger.debug('CLI commands registered successfully');
    try {
        await program.parseAsync(args, { from: 'user' });
        cliLogger.debug('CLI arguments parsed and command executed');
    }
    catch (error) {
        cliLogger.error('Error during CLI execution', error);
        // Commander already handles displaying errors, so we might not need to do more here
        // unless we want custom global error handling for CLI.
        process.exit(1); // Ensure non-zero exit code on error
    }
}
