"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatExportSummary = formatExportSummary;
const formatter_util_js_1 = require("../utils/formatter.util.js");
function formatExportSummary(summary) {
    const lines = [];
    lines.push((0, formatter_util_js_1.formatHeading)(`Confluence Export Summary for Space: ${summary.spaceKey} (${summary.spaceName || 'N/A'})`, 1));
    lines.push('');
    const details = {
        'Space Key': summary.spaceKey,
        'Space Name': summary.spaceName || 'N/A',
        'Pages Found': summary.pagesFound,
        'Pages Exported': summary.pagesExported,
        'Pages Skipped': summary.pagesSkipped || 0,
        'Output Directory': summary.outputDir,
        'Export Format': summary.format,
        // Add more details as implemented
    };
    if (summary.totalTimeSeconds !== undefined) {
        details['Total Time'] = `${summary.totalTimeSeconds} seconds`;
    }
    lines.push((0, formatter_util_js_1.formatBulletList)(details));
    lines.push('');
    if (summary.ignoredFilters && summary.ignoredFilters.length > 0) {
        lines.push((0, formatter_util_js_1.formatHeading)('Applied Filters:', 2));
        lines.push(...summary.ignoredFilters.map((filter) => `- \`${filter}\``));
        lines.push('');
    }
    if (summary.errors && summary.errors.length > 0) {
        lines.push((0, formatter_util_js_1.formatHeading)('Errors Encountered:', 2));
        lines.push(...summary.errors.map((e) => `- ${e}`));
        lines.push('');
    }
    lines.push('');
    lines.push((0, formatter_util_js_1.formatSeparator)());
    lines.push(`*Export process finished at: ${(0, formatter_util_js_1.formatDate)(new Date())}*`);
    return lines.join('\n');
}
