#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_util_js_1 = require("./utils/logger.util.js");
const config_util_js_1 = require("./utils/config.util.js");
const index_js_1 = require("./cli/index.js");
const indexLogger = logger_util_js_1.Logger.forContext('index.ts');
indexLogger.debug('Confluence Export CLI tool module loaded');
async function main() {
    const mainLogger = logger_util_js_1.Logger.forContext('index.ts', 'main');
    config_util_js_1.config.load(); // Load configuration
    mainLogger.debug(`DEBUG environment variable: ${process.env.DEBUG}`);
    // Add any Confluence specific config checks here if needed
    // e.g., mainLogger.debug(`ATLASSIAN_API_TOKEN exists: ${Boolean(process.env.ATLASSIAN_API_TOKEN)}`);
    // Always run in CLI mode
    mainLogger.info('Starting in CLI mode');
    await (0, index_js_1.runCli)(process.argv.slice(2)); // Pass all args after 'node' and 'index.js'
    mainLogger.info('CLI execution completed');
}
if (require.main === module) {
    main().catch((err) => {
        indexLogger.error('Unhandled error in main process', err);
        process.exit(1);
    });
}
