import { z } from 'zod';
export declare const PaginatedResponseSchema: <T extends z.ZodTypeAny>(itemSchema: T) => z.ZodObject<{
    results: z.ZodArray<T, "many">;
    start: z.ZodOptional<z.ZodNumber>;
    limit: z.ZodOptional<z.ZodNumber>;
    size: z.ZodOptional<z.ZodNumber>;
    _links: z.ZodOptional<z.ZodObject<{
        next: z.ZodOptional<z.ZodString>;
        base: z.ZodOptional<z.ZodString>;
        context: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        next?: string | undefined;
        base?: string | undefined;
        context?: string | undefined;
    }, {
        next?: string | undefined;
        base?: string | undefined;
        context?: string | undefined;
    }>>;
    next: z.ZodOptional<z.ZodObject<{
        cursor: z.ZodString;
        _links: z.ZodObject<{
            next: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            next: string;
        }, {
            next: string;
        }>;
    }, "strip", z.ZodTypeAny, {
        cursor: string;
        _links: {
            next: string;
        };
    }, {
        cursor: string;
        _links: {
            next: string;
        };
    }>>;
}, "strip", z.ZodTypeAny, {
    results: T["_output"][];
    start?: number | undefined;
    limit?: number | undefined;
    size?: number | undefined;
    next?: {
        cursor: string;
        _links: {
            next: string;
        };
    } | undefined;
    _links?: {
        next?: string | undefined;
        base?: string | undefined;
        context?: string | undefined;
    } | undefined;
}, {
    results: T["_input"][];
    start?: number | undefined;
    limit?: number | undefined;
    size?: number | undefined;
    next?: {
        cursor: string;
        _links: {
            next: string;
        };
    } | undefined;
    _links?: {
        next?: string | undefined;
        base?: string | undefined;
        context?: string | undefined;
    } | undefined;
}>;
export type PaginatedResponse<T> = z.infer<ReturnType<typeof PaginatedResponseSchema<z.ZodType<T>>>>;
export declare const ConfluenceSpaceSchema: z.ZodObject<{
    id: z.ZodString;
    key: z.ZodString;
    name: z.ZodString;
    type: z.ZodOptional<z.ZodString>;
    status: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    key: string;
    id: string;
    name: string;
    type?: string | undefined;
    status?: string | undefined;
}, {
    key: string;
    id: string;
    name: string;
    type?: string | undefined;
    status?: string | undefined;
}>;
export type ConfluenceSpace = z.infer<typeof ConfluenceSpaceSchema>;
export declare const ConfluenceSpaceDetailedSchema: z.ZodObject<{
    id: z.ZodString;
    key: z.ZodString;
    name: z.ZodString;
    type: z.ZodOptional<z.ZodString>;
    status: z.ZodOptional<z.ZodString>;
} & {
    description: z.ZodOptional<z.ZodOptional<z.ZodNullable<z.ZodAny>>>;
    homepageId: z.ZodOptional<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
}, "strip", z.ZodTypeAny, {
    key: string;
    id: string;
    name: string;
    type?: string | undefined;
    status?: string | undefined;
    description?: any;
    homepageId?: string | null | undefined;
}, {
    key: string;
    id: string;
    name: string;
    type?: string | undefined;
    status?: string | undefined;
    description?: any;
    homepageId?: string | null | undefined;
}>;
export type ConfluenceSpaceDetailed = z.infer<typeof ConfluenceSpaceDetailedSchema>;
export declare const ConfluencePageBodyStorageSchema: z.ZodObject<{
    value: z.ZodString;
    representation: z.ZodLiteral<"storage">;
}, "strip", z.ZodTypeAny, {
    value: string;
    representation: "storage";
}, {
    value: string;
    representation: "storage";
}>;
export type ConfluencePageBodyStorage = z.infer<typeof ConfluencePageBodyStorageSchema>;
export declare const ConfluencePageBodyViewSchema: z.ZodObject<{
    value: z.ZodString;
    representation: z.ZodLiteral<"view">;
}, "strip", z.ZodTypeAny, {
    value: string;
    representation: "view";
}, {
    value: string;
    representation: "view";
}>;
export type ConfluencePageBodyView = z.infer<typeof ConfluencePageBodyViewSchema>;
export declare const ConfluenceVersionSchema: z.ZodObject<{
    number: z.ZodNumber;
    createdAt: z.ZodOptional<z.ZodString>;
    when: z.ZodOptional<z.ZodString>;
    message: z.ZodOptional<z.ZodString>;
    minorEdit: z.ZodOptional<z.ZodBoolean>;
    authorId: z.ZodOptional<z.ZodString>;
    by: z.ZodOptional<z.ZodObject<{
        accountId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        accountId: string;
    }, {
        accountId: string;
    }>>;
    ncsStepVersion: z.ZodOptional<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
}, "strip", z.ZodTypeAny, {
    number: number;
    message?: string | undefined;
    createdAt?: string | undefined;
    when?: string | undefined;
    minorEdit?: boolean | undefined;
    authorId?: string | undefined;
    by?: {
        accountId: string;
    } | undefined;
    ncsStepVersion?: string | null | undefined;
}, {
    number: number;
    message?: string | undefined;
    createdAt?: string | undefined;
    when?: string | undefined;
    minorEdit?: boolean | undefined;
    authorId?: string | undefined;
    by?: {
        accountId: string;
    } | undefined;
    ncsStepVersion?: string | null | undefined;
}>;
export type ConfluenceVersion = z.infer<typeof ConfluenceVersionSchema>;
export declare const ConfluencePageAncestorSchema: z.ZodObject<{
    id: z.ZodString;
    title: z.ZodString;
}, "strip", z.ZodTypeAny, {
    id: string;
    title: string;
}, {
    id: string;
    title: string;
}>;
export type ConfluencePageAncestor = z.infer<typeof ConfluencePageAncestorSchema>;
export declare const ConfluencePageV2Schema: z.ZodObject<{
    id: z.ZodString;
    spaceId: z.ZodString;
    status: z.ZodString;
    title: z.ZodString;
    parentId: z.ZodOptional<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
    position: z.ZodOptional<z.ZodNumber>;
    createdAt: z.ZodString;
    version: z.ZodOptional<z.ZodObject<{
        number: z.ZodNumber;
        message: z.ZodOptional<z.ZodString>;
        minorEdit: z.ZodOptional<z.ZodBoolean>;
        authorId: z.ZodOptional<z.ZodString>;
        createdAt: z.ZodOptional<z.ZodString>;
        ncsStepVersion: z.ZodOptional<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
    }, "strip", z.ZodTypeAny, {
        number: number;
        message?: string | undefined;
        createdAt?: string | undefined;
        minorEdit?: boolean | undefined;
        authorId?: string | undefined;
        ncsStepVersion?: string | null | undefined;
    }, {
        number: number;
        message?: string | undefined;
        createdAt?: string | undefined;
        minorEdit?: boolean | undefined;
        authorId?: string | undefined;
        ncsStepVersion?: string | null | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    status: string;
    id: string;
    createdAt: string;
    title: string;
    spaceId: string;
    parentId?: string | null | undefined;
    position?: number | undefined;
    version?: {
        number: number;
        message?: string | undefined;
        createdAt?: string | undefined;
        minorEdit?: boolean | undefined;
        authorId?: string | undefined;
        ncsStepVersion?: string | null | undefined;
    } | undefined;
}, {
    status: string;
    id: string;
    createdAt: string;
    title: string;
    spaceId: string;
    parentId?: string | null | undefined;
    position?: number | undefined;
    version?: {
        number: number;
        message?: string | undefined;
        createdAt?: string | undefined;
        minorEdit?: boolean | undefined;
        authorId?: string | undefined;
        ncsStepVersion?: string | null | undefined;
    } | undefined;
}>;
export type ConfluencePageV2 = z.infer<typeof ConfluencePageV2Schema>;
export declare const ConfluencePageDetailedV2Schema: z.ZodObject<{
    id: z.ZodString;
    spaceId: z.ZodString;
    status: z.ZodString;
    title: z.ZodString;
    parentId: z.ZodOptional<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
    position: z.ZodOptional<z.ZodNumber>;
    createdAt: z.ZodString;
} & {
    body: z.ZodObject<{
        storage: z.ZodOptional<z.ZodObject<{
            value: z.ZodString;
            representation: z.ZodLiteral<"storage">;
        }, "strip", z.ZodTypeAny, {
            value: string;
            representation: "storage";
        }, {
            value: string;
            representation: "storage";
        }>>;
        view: z.ZodOptional<z.ZodObject<{
            value: z.ZodString;
            representation: z.ZodLiteral<"view">;
        }, "strip", z.ZodTypeAny, {
            value: string;
            representation: "view";
        }, {
            value: string;
            representation: "view";
        }>>;
    }, "strip", z.ZodTypeAny, {
        storage?: {
            value: string;
            representation: "storage";
        } | undefined;
        view?: {
            value: string;
            representation: "view";
        } | undefined;
    }, {
        storage?: {
            value: string;
            representation: "storage";
        } | undefined;
        view?: {
            value: string;
            representation: "view";
        } | undefined;
    }>;
    version: z.ZodObject<{
        number: z.ZodNumber;
        createdAt: z.ZodOptional<z.ZodString>;
        when: z.ZodOptional<z.ZodString>;
        message: z.ZodOptional<z.ZodString>;
        minorEdit: z.ZodOptional<z.ZodBoolean>;
        authorId: z.ZodOptional<z.ZodString>;
        by: z.ZodOptional<z.ZodObject<{
            accountId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            accountId: string;
        }, {
            accountId: string;
        }>>;
        ncsStepVersion: z.ZodOptional<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
    }, "strip", z.ZodTypeAny, {
        number: number;
        message?: string | undefined;
        createdAt?: string | undefined;
        when?: string | undefined;
        minorEdit?: boolean | undefined;
        authorId?: string | undefined;
        by?: {
            accountId: string;
        } | undefined;
        ncsStepVersion?: string | null | undefined;
    }, {
        number: number;
        message?: string | undefined;
        createdAt?: string | undefined;
        when?: string | undefined;
        minorEdit?: boolean | undefined;
        authorId?: string | undefined;
        by?: {
            accountId: string;
        } | undefined;
        ncsStepVersion?: string | null | undefined;
    }>;
    ancestors: z.ZodOptional<z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        title: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        title: string;
    }, {
        id: string;
        title: string;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    status: string;
    id: string;
    createdAt: string;
    title: string;
    spaceId: string;
    version: {
        number: number;
        message?: string | undefined;
        createdAt?: string | undefined;
        when?: string | undefined;
        minorEdit?: boolean | undefined;
        authorId?: string | undefined;
        by?: {
            accountId: string;
        } | undefined;
        ncsStepVersion?: string | null | undefined;
    };
    body: {
        storage?: {
            value: string;
            representation: "storage";
        } | undefined;
        view?: {
            value: string;
            representation: "view";
        } | undefined;
    };
    parentId?: string | null | undefined;
    position?: number | undefined;
    ancestors?: {
        id: string;
        title: string;
    }[] | undefined;
}, {
    status: string;
    id: string;
    createdAt: string;
    title: string;
    spaceId: string;
    version: {
        number: number;
        message?: string | undefined;
        createdAt?: string | undefined;
        when?: string | undefined;
        minorEdit?: boolean | undefined;
        authorId?: string | undefined;
        by?: {
            accountId: string;
        } | undefined;
        ncsStepVersion?: string | null | undefined;
    };
    body: {
        storage?: {
            value: string;
            representation: "storage";
        } | undefined;
        view?: {
            value: string;
            representation: "view";
        } | undefined;
    };
    parentId?: string | null | undefined;
    position?: number | undefined;
    ancestors?: {
        id: string;
        title: string;
    }[] | undefined;
}>;
export type ConfluencePageDetailedV2 = z.infer<typeof ConfluencePageDetailedV2Schema>;
export declare const BaseConfluenceContentSchema: z.ZodObject<{
    id: z.ZodString;
    type: z.ZodString;
    status: z.ZodString;
    title: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    type: string;
    status: string;
    id: string;
    title?: string | undefined;
}, {
    type: string;
    status: string;
    id: string;
    title?: string | undefined;
}>;
export declare const ConfluencePageContentSchema: z.ZodObject<{
    id: z.ZodString;
    status: z.ZodString;
} & {
    type: z.ZodLiteral<"page">;
    title: z.ZodString;
    _expandable: z.ZodOptional<z.ZodObject<{
        ancestors: z.ZodOptional<z.ZodString>;
        body: z.ZodOptional<z.ZodString>;
        version: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        version?: string | undefined;
        body?: string | undefined;
        ancestors?: string | undefined;
    }, {
        version?: string | undefined;
        body?: string | undefined;
        ancestors?: string | undefined;
    }>>;
    body: z.ZodOptional<z.ZodObject<{
        storage: z.ZodOptional<z.ZodObject<{
            value: z.ZodString;
            representation: z.ZodLiteral<"storage">;
        }, "strip", z.ZodTypeAny, {
            value: string;
            representation: "storage";
        }, {
            value: string;
            representation: "storage";
        }>>;
        view: z.ZodOptional<z.ZodObject<{
            value: z.ZodString;
            representation: z.ZodLiteral<"view">;
        }, "strip", z.ZodTypeAny, {
            value: string;
            representation: "view";
        }, {
            value: string;
            representation: "view";
        }>>;
    }, "strip", z.ZodTypeAny, {
        storage?: {
            value: string;
            representation: "storage";
        } | undefined;
        view?: {
            value: string;
            representation: "view";
        } | undefined;
    }, {
        storage?: {
            value: string;
            representation: "storage";
        } | undefined;
        view?: {
            value: string;
            representation: "view";
        } | undefined;
    }>>;
    version: z.ZodOptional<z.ZodObject<{
        number: z.ZodNumber;
        createdAt: z.ZodOptional<z.ZodString>;
        when: z.ZodOptional<z.ZodString>;
        message: z.ZodOptional<z.ZodString>;
        minorEdit: z.ZodOptional<z.ZodBoolean>;
        authorId: z.ZodOptional<z.ZodString>;
        by: z.ZodOptional<z.ZodObject<{
            accountId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            accountId: string;
        }, {
            accountId: string;
        }>>;
        ncsStepVersion: z.ZodOptional<z.ZodOptional<z.ZodNullable<z.ZodString>>>;
    }, "strip", z.ZodTypeAny, {
        number: number;
        message?: string | undefined;
        createdAt?: string | undefined;
        when?: string | undefined;
        minorEdit?: boolean | undefined;
        authorId?: string | undefined;
        by?: {
            accountId: string;
        } | undefined;
        ncsStepVersion?: string | null | undefined;
    }, {
        number: number;
        message?: string | undefined;
        createdAt?: string | undefined;
        when?: string | undefined;
        minorEdit?: boolean | undefined;
        authorId?: string | undefined;
        by?: {
            accountId: string;
        } | undefined;
        ncsStepVersion?: string | null | undefined;
    }>>;
    ancestors: z.ZodOptional<z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        title: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        title: string;
    }, {
        id: string;
        title: string;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    type: "page";
    status: string;
    id: string;
    title: string;
    version?: {
        number: number;
        message?: string | undefined;
        createdAt?: string | undefined;
        when?: string | undefined;
        minorEdit?: boolean | undefined;
        authorId?: string | undefined;
        by?: {
            accountId: string;
        } | undefined;
        ncsStepVersion?: string | null | undefined;
    } | undefined;
    body?: {
        storage?: {
            value: string;
            representation: "storage";
        } | undefined;
        view?: {
            value: string;
            representation: "view";
        } | undefined;
    } | undefined;
    ancestors?: {
        id: string;
        title: string;
    }[] | undefined;
    _expandable?: {
        version?: string | undefined;
        body?: string | undefined;
        ancestors?: string | undefined;
    } | undefined;
}, {
    type: "page";
    status: string;
    id: string;
    title: string;
    version?: {
        number: number;
        message?: string | undefined;
        createdAt?: string | undefined;
        when?: string | undefined;
        minorEdit?: boolean | undefined;
        authorId?: string | undefined;
        by?: {
            accountId: string;
        } | undefined;
        ncsStepVersion?: string | null | undefined;
    } | undefined;
    body?: {
        storage?: {
            value: string;
            representation: "storage";
        } | undefined;
        view?: {
            value: string;
            representation: "view";
        } | undefined;
    } | undefined;
    ancestors?: {
        id: string;
        title: string;
    }[] | undefined;
    _expandable?: {
        version?: string | undefined;
        body?: string | undefined;
        ancestors?: string | undefined;
    } | undefined;
}>;
export type ConfluencePage = z.infer<typeof ConfluencePageContentSchema>;
